<h1 align="center">
<img src="https://raw.githubusercontent.com/jgherruzo/pyPETB/main/logo/current/pyPETB_logo.png" width="300">
</h1><br>

# THE PROCESS ENGINEER TOOLBOX

[![python](https://img.shields.io/badge/python-_3.11-blue.svg?logo=python)](https://www.python.org)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Process Engineer Tool Box is a package where a set of tools are developed to help in our daily tasks. It is based in the use of pandas. In daily chemical industry task, focused on data analysis
and improvement projects developing, no long dataset are
usually used and pandas cover all the requirements.

## 2- INSTALLATION

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pyPETB.

```bash
pip install pypetb
```

## 3- USAGE

Please refer to the [Documentation](https://pypetb.readthedocs.io/en/latest/)

Gage R&R [use case](https://medium.com/@jgherruzo/enhancing-industrial-processes-improvement-cycle-with-python-chapter-1-introducing-pypetbs-gage-7a7a9a952052)

Capability Analysis [use case](https://medium.com/@jgherruzo/enhancing-industrial-processes-improvement-cycle-with-python-ii-introducing-pypetbs-capability-0865840896a6)

Automate Gage Repeatability [use case](https://medium.com/@jgherruzo/enhancing-industrial-processes-improvement-cycle-with-python-iii-automatic-measurement-gage-f0e2929a3ffc)

## 4- LICENSE

Distributed under the [MIT License](https://github.com/jgherruzo/pyPETB/blob/main/LICENSE.txt).

## 5- ROADMAP

- Package development is considered as finished. There are DOE functions already developed to lead with these features and no gap is detected rigth now. I'm available for any recommendation about improvements or feature additions.

## 6- ACKNOLEDGMENTS

- Thanks to Noël Santiago for his coaching during our six sigma green belt training
- Thanks to Ted Hessing for his detailed article calculating RnR
- Thanks to Linus Isberg Martinsson for his effort developing improvements for this package

![Visual Studio Code](https://img.shields.io/badge/Visual%20Studio%20Code-blue?logo=visual%20studio%20code)
![Poetry](https://img.shields.io/badge/Poetry-blue?logo=poetry)
![ReadTheDocs](https://img.shields.io/badge/ReadTheDocs-blue?logo=readthedocs)
